[![Dependency Review](https://github.com/minggnim/nlp-classification-model/actions/workflows/dependency-review.yml/badge.svg)](https://github.com/minggnim/nlp-classification-model/actions/workflows/dependency-review.yml)
[![Python package](https://github.com/minggnim/nlp-classification-model/actions/workflows/python-package.yml/badge.svg)](https://github.com/minggnim/nlp-classification-model/actions/workflows/python-package.yml)
[![Upload Python Package](https://github.com/minggnim/nlp-classification-model/actions/workflows/python-publish.yml/badge.svg)](https://github.com/minggnim/nlp-classification-model/actions/workflows/python-publish.yml)

# NLP Models

A repository for training transformer based nlp models

## Example Notebooks

1. [Training](https://github.com/minggnim/nlp-classification-model/blob/master/notebooks/01_custom_training_example.ipynb)
2. [Inference](https://github.com/minggnim/nlp-classification-model/blob/master/notebooks/02_inference_example.ipynb)

## Installation

### Install from PyPi

```
pip install nlp_models
```

### Install from source

```
git clone git@github.com:minggnim/nlp-models.git
pip install -r requirements
```
